// ****************************************************************************************************************
// Author: Marcin Załęczny
// Web: http://progmar.net.pl
// Email: mzaleczny@gmail.com
// Required: Mootools 1.4.4
// Version: mzmenu 1.1
// Based on roll-out lists described in Richard York's book: Gotowe rozwiązania CSS (Ready to use solutions in CSS)
// ****************************************************************************************************************

var MzBaseMenu = new Class({
	Implements: [Events,Options],
	
	options: {
		width: 400,
		height: 150,
		item_height: 30,
		item_width: 120,
		menu_items: null
	},
	
	initialize: function(container, options, data) {
		this.setOptions(options);
		this.container = $(container);
		if (!this.container) {
			return;
		}
		this.create();
	},
	
	create: function() {
	}
});


var MzVerticalMenu = new Class({
	Extends: MzBaseMenu,
	
	create: function() {
		this.root = new Element('ul', {'class': 'mzvmenu'});
		this.root.setStyles({'width':this.options.width, 'height':this.options.height});
		this.container.appendChild(this.root);
		this.container.setStyles({'width':this.options.width, 'height':this.options.height});
		
		var li, a, span;
		
		if (this.options.menu_items && this.options.menu_items.length > 0) {
			for (var i = 0; i < this.options.menu_items.length; i++) {
				var item = this.options.menu_items[i];
				var has_menuitems = item.menu_items && item.menu_items.length > 0;
				
				li = new Element('li', {'class': 'mzvmenu'});
				li.setStyles({'width':this.options.width, 'height':this.options.item_height});
				this.root.appendChild(li);
				
				a = new Element('a', {'href': item.url});
				a.setStyles({'width': this.options.width, 'height':this.options.item_height});
				span = new Element('span');
				span.setStyles({'width': this.options.width, 'height':this.options.item_height});
				span.set('html', item.caption);
				a.appendChild(span);
				li.appendChild(a);
				
				if (has_menuitems) {
					this.buildSubmenu(li, item.menu_items);
				}
			}
		}
	},
	
	buildSubmenu: function(container, menu_items) {
		var li = null;
		var span = null;
		var span_arrow = null;
		var div = null;
		var ul = null;
		var items_count = 0;
		
		if (menu_items && menu_items.length > 0) {
			items_count = menu_items.length;
		}
		
		if (items_count == 0) {
			return;
		}
		
		if (container.tagName == 'LI') {
			ul = new Element('ul');
			ul.setStyles({'width': this.options.item_width+4});
			var parent = container.getParent();
			var left = parent.getStyle('width').toInt();
			ul.setStyle('left', left);
			ul.setStyle('z-index', 100);
			container.appendChild(ul);
		}
		
		if (menu_items) {
			for (var i = 0; i < menu_items.length; i++) {
				var item = menu_items[i];
				
				li = new Element('li');
				if (item.menu_items && item.menu_items.length > 0) {
					li.addClass('mzvmenu');
				}
				li.setStyles({'width': this.options.item_width, 'height':this.options.item_height});
				ul.appendChild(li);
				
				a = new Element('a', {'href': item.url});
				a.setStyles({'width': this.options.item_width, 'height':this.options.item_height});
				span = new Element('span');
				span.setStyles({'width': this.options.item_width, 'height':this.options.item_height});
				span.set('html', item.caption);
				a.appendChild(span);
				li.appendChild(a);
				
				if (item.menu_items && item.menu_items.length > 0) {
					this.buildSubmenu(li, item.menu_items);
				}
				
				//span.addEvent('mouseover', this.onMenuItemMouseOver.bind(this, span));
				//span.addEvent('mouseout', this.onMenuItemMouseOut.bind(this, span));
			}
		}
	},
	
	onMenuItemClick: function(tab) {
	},
	
	onMenuItemMouseOver: function(span) {
	},
	
	onMenuItemMouseOut: function(span) {
	}
});

var MzHorizontalMenu = new Class({
	Extends: MzBaseMenu,
	
	create: function() {
		this.container.setStyle('position', 'relative');
		this.root = new Element('ul', {'class': 'mzhmenu'});
		this.root.addClass('mzhmenu-root');
		this.root.setStyles({'width':this.options.width, 'height':this.options.height});
		this.container.appendChild(this.root);
		this.container.setStyles({'width':this.options.width, 'height':this.options.height});
		
		var li, a, span;
		
		if (this.options.menu_items && this.options.menu_items.length > 0) {
			var left = 0;
			var top = 0;
			for (var i = 0; i < this.options.menu_items.length; i++) {
				var item = this.options.menu_items[i];
				var has_menuitems = item.menu_items && item.menu_items.length > 0;
				
				var item_width = item.width ? item.width : 100;
				var item_height = this.options.item_height ? this.options.item_height : 33;
				
				li = new Element('li', {'class': 'mzhmenu'});
				li.setStyles({'width':item_width, 'height':item_height, 'left': left, 'top': top});
				li.addClass('li-root');
				this.root.appendChild(li);
				left += item_width + 4;
				
				a = new Element('a', {'href': item.url});
				a.setStyles({'width': item_width, 'height':item_height});
				// Main menu item has no arrow
				a.addClass('noarrow');
				span = new Element('span');
				span.setStyles({'width': item_width, 'height':item_height});
				span.set('html', item.caption);
				a.appendChild(span);
				li.appendChild(a);
				
				if (has_menuitems) {
					this.buildSubmenu(li, item, item.menu_items);
				}
			}
		}
	},
	
	buildSubmenu: function(container, item, menu_items) {
		var li = null;
		var span = null;
		var span_arrow = null;
		var div = null;
		var ul = null;
		var items_count = 0;
		
		if (menu_items && menu_items.length > 0) {
			items_count = menu_items.length;
		}
		
		if (items_count == 0) {
			return;
		}
		
		if (!item.submenu_width) {
			item.submenu_width = 120;
		}
		
		var parent = container.getParent();
		var left = parent ? parent.getStyle('left').toInt(): 0;
		var top  = parent ? parent.getStyle('top').toInt() + 3 + this.options.item_height: 0;
		if (container.tagName == 'LI') {
			ul = new Element('ul');
			if (items_count > 0) {
				ul.addClass('mzhmenu');
			}
			if (container.hasClass('li-root')) {
				// If we add popup to root li, then position it below
				ul.setStyles({'position': 'absolute', 'width': item.submenu_width, 'height': items_count * (this.options.item_height+2)+4,
							  'left': left, 'top': top});
			} else {
				// else position it to the right
				ul.setStyles({'position': 'absolute', 'width': item.submenu_width,
							  'height': items_count * (this.options.item_height+4),
							  'left': parent.getStyle('width').toInt() + 1, 'top': 0});
			}
			ul.setStyle('z-index', 100);
			container.appendChild(ul);
		}
		
		if (menu_items) {
			top = 0;
			left = 0;
			for (var i = 0; i < menu_items.length; i++) {
				var sub_item = menu_items[i];
				
				li = new Element('li');
				if (sub_item.menu_items && sub_item.menu_items.length > 0) {
					li.addClass('mzhmenu');
				}
				li.setStyles({'left': left, 'top': top, 'width': item.submenu_width-4, 'height':this.options.item_height});
				ul.appendChild(li);
				top += this.options.height;
				
				a = new Element('a', {'href': sub_item.url});
				a.setStyles({'width': ul.getStyle('width').toInt()-3, 'height':this.options.item_height});
				span = new Element('span');
				span.setStyles({'width': ul.getStyle('width').toInt()-3, 'height':this.options.item_height});
				span.set('html', sub_item.caption);
				a.appendChild(span);
				li.appendChild(a);
				
				if (sub_item.menu_items && sub_item.menu_items.length > 0) {
					this.buildSubmenu(li, sub_item, sub_item.menu_items);
				}
				
				//span.addEvent('mouseover', this.onMenuItemMouseOver.bind(this, span));
				//span.addEvent('mouseout', this.onMenuItemMouseOut.bind(this, span));
			}
		}
	},
	
	onMenuItemClick: function(tab) {
	},
	
	onMenuItemMouseOver: function(span) {
	},
	
	onMenuItemMouseOut: function(span) {
	}
});
